@@ -51,6 +51,7 @@ def create_configuration(file_path=None, config_data=None, required_components=[
 # config_package/__init__.py
 
 from locobuzz_python_configuration.config_builder import ConfigurationBuilder
+from locobuzz_python_configuration.redis_config_builder import RedisConfigurationBuilder
 from locobuzz_python_configuration.sql_config_builder import SQLConfigurationBuilder
 from locobuzz_python_configuration.clickhouse_config_builder import ClickHouseConfigurationBuilder
 from locobuzz_python_configuration.aws_config_builder import AWSConfigurationBuilder
@@ -68,6 +69,7 @@ def create_configuration(file_path=None, config_data=None, required_components=[
         'aws': AWSConfigurationBuilder,
         'elastic': ElasticSearchConfigurationBuilder,
         'kafka': KafkaConfigurationBuilder,
+        'redis': RedisConfigurationBuilder
     }
 
     # Merge default builders with provided builders, if any
@@ -85,6 +87,8 @@ def create_configuration(file_path=None, config_data=None, required_components=[
         builder.set_elastic_builder(default_builders['elastic'](builder.get_configuration()))
     if 'kafka' in default_builders:
         builder.set_kafka_builder(default_builders['kafka'](builder.get_configuration()))
+    if 'redis' in default_builders:
+        builder.set_redis_builder(default_builders['redis'](builder.get_configuration()))
 
     try:
         if file_path:
@@ -99,9 +103,9 @@ def create_configuration(file_path=None, config_data=None, required_components=[
         print(f"Error creating configuration: {e}")
         raise e
 
-# if __name__ == "__main__":
-#     CONFIG = create_configuration(file_path='appsettings.json', required_components=["sql", "kafka"])
-#     print(CONFIG.__dict__)
-#     SERVICE_NAME = "FACEBOOK_PAGE_INSIGHT_READER_SERVICE"
-#     IS_ASYNC_LOGGER = CONFIG.__dict__.get('_is_async_logger', False)
+if __name__ == "__main__":
+    CONFIG = create_configuration(file_path='appsettings.json', required_components=["redis", "kafka"])
+    print(CONFIG.__dict__)
+    SERVICE_NAME = "FACEBOOK_PAGE_INSIGHT_READER_SERVICE"
+    IS_ASYNC_LOGGER = CONFIG.__dict__.get('_is_async_logger', False)
 
