@@ -44,6 +44,7 @@ class Configuration:
 
 class ConfigurationBuilder:
     def __init__(self):
+        self._redis_builder = None
         self._configuration = Configuration()
         self._sql_builder = None
         self._clickhouse_builder = None
@@ -108,7 +109,8 @@ class ConfigurationBuilder:
                 "dead_letter_topic_name": {"type": "string"},
                 "g_chat_hook": {"type": "string"},
                 "g_chat_error_hook": {"type": "string"},
-                "log_enabled": {"type": "string"}
+                "log_enabled": {"type": "string"},
+                "redis_host": {"type": "string"}
             },
             "required": ["environ", "log_enabled", "is_async_logger", "log_level"]
         }
@@ -155,6 +157,8 @@ class ConfigurationBuilder:
             self._elastic_builder.build(data)
         if self._kafka_builder:
             self._kafka_builder.build(data)
+        if self._redis_builder:
+            self._redis_builder.build(data)
 
     def set_sql_builder(self, builder):
         self._sql_builder = builder
@@ -171,5 +175,8 @@ class ConfigurationBuilder:
     def set_kafka_builder(self, builder):
         self._kafka_builder = builder
 
+    def set_redis_builder(self, builder):
+        self._redis_builder = builder
+
     def get_configuration(self):
         return self._configuration
